Learn R Programming

CNVPanelizer (version 1.2.2)

IndexMultipleBams: IndexMultipleBams

Description

Index a list of bam files if there is no index exists for the file entries in the list.

Usage

IndexMultipleBams(bams, index_type = ".bam.bai")

Arguments

bams
A character vector of bam files to be indexed
index_type
The index file type extension

Value

Not returning any value

Examples

Run this code
    
    
    
        files = c("file1.bam","file2.bam","file3.bam")
        IndexMultipleBams(bams = files)
    

Run the code above in your browser using DataLab