It generates a GenomicRanges object from a bed file.
Needs to be passed the correct number of the gene name column.
If the strings contain more information then just the gene name,
a splitting character (split) has to be defined. I.e GeneName1;Amplicon2