lc{
Our approach uses a non-parametric bootstrap subsampling of the available
reference samples, to estimate the distribution of read counts from targeted
sequencing. As inspired by random forest, this is combined at each iteration
with a procedure that subsamples the amplicons associated with each of the targeted genes.
To estimate the background noise of sequencing genes with a low number of amplicons
a second subsampling step is performed. Both steps are combined to make a decision
on the CNV status. Thus classifying the copy number aberrations on the gene level.
}
For a complete list of functions, use library(help = "CNVPanelizer").ll{
Package: CNVPanelizer
Type: Package
License: GPL-3
}